LogInfo class

Log information of each log entry.

Constructors

LogInfo(LogLevel level, String tag, String message, bool useIsLoggable)

Properties

hashCode int
The hash code for this object.
no setterinherited
level LogLevel
final
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag String
final
timestamp DateTime
Timestamp when this log entry is created. Note that this value is not as same as timestamp in platform logging system.
final
useIsLoggable bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited