timestamp property
Timestamp when this log entry is created. Note that this value is not as same as timestamp in platform logging system.
Implementation
final DateTime timestamp = DateTime.now();
Timestamp when this log entry is created. Note that this value is not as same as timestamp in platform logging system.
final DateTime timestamp = DateTime.now();